@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Moose;
 use Moose::Util::TypeConstraints qw(enum);
@@ -68,6 +68,8 @@ sub add_badges {
     foreach my $badge (@{$self->badges}) {
         if ($badge eq 'travis') {
             push @badges, "[![Build Status](https://travis-ci.org/$user_name/$repository_name.svg?branch=master)](https://travis-ci.org/$user_name/$repository_name)";
+        } elsif ($badge eq 'appveyor') {
+            push @badges, "[![AppVeyor Status](https://ci.appveyor.com/api/projects/status/github/$user_name/$repository_name?branch=master&svg=true)](https://ci.appveyor.com/project/$user_name/$repository_name)";
         } elsif ($badge eq 'coveralls') {
             push @badges, "[![Coverage Status](https://coveralls.io/repos/$user_name/$repository_name/badge.svg?branch=master)](https://coveralls.io/r/$user_name/$repository_name?branch=master)"
         } elsif ($badge eq 'gitter') {
@@ -89,8 +91,6 @@ sub add_badges {
         } elsif ($badge eq 'gitlab_cover') {
             push @badges, "[![coverage report](https://$base_url/$user_name/$repository_name/badges/master/coverage.svg)]($repository/$user_name/$repository_name/commits/master)";
         }
-		
-		
     }
 
     if ($self->place eq 'bottom') {
@@ -119,6 +119,7 @@ Dist::Zilla::Plugin::GitHubREADME::Badge - Dist::Zilla - add badges to github RE
     # configure it yourself
     [GitHubREADME::Badge]
     badges = travis
+    badges = appveyor
     badges = coveralls
     badges = gitter
     badges = cpants
